@@ -1,5 +1,5 @@
 package WWW::Mailman;
-
+$WWW::Mailman::VERSION = '1.061';
 use warnings;
 use strict;
 
@@ -8,8 +8,6 @@ use URI;
 use WWW::Mechanize;
 use HTTP::Cookies;
 
-our $VERSION = '1.06';
-
 my @attributes = qw(
     secure server prefix program list
     email password moderator_password admin_password
@@ -82,6 +80,11 @@ sub uri {
     return $uri;
 }
 
+sub archive_mbox_uri {
+    my $self = shift;
+    return $self->__uri_for( private => ( $self->list . '.mbox' ) x 2 );
+}
+
 sub userinfo {
     my $self = shift;
     return defined $self->{userinfo} ? $self->{userinfo} : '' if !@_;
@@ -127,7 +130,7 @@ sub new {
     # bring in the robot if needed
     if ( !$self->robot ) {
         my %mech_options = (
-            agent => "WWW::Mailman/$VERSION",
+            agent => "WWW::Mailman/$WWW::Mailman::VERSION",
             stack_depth => 2,    # make it a Bear of Very Little Brain
             quiet       => 1,
             autocheck   => 0,    # Fancy my making a mistake like that
@@ -150,18 +153,22 @@ sub new {
 #
 # PRIVATE METHODS
 #
-sub _uri_for {
-    my ( $self, $action, @options ) = @_;
+sub __uri_for {
+    my ( $self, @parts ) = @_;
     my $uri = URI->new();
     $uri->scheme( $self->secure ? 'https' : 'http' );
     $uri->userinfo( $self->userinfo )
         if $self->userinfo;
     $uri->host( $self->server );
-    $uri->path( join '/', $self->prefix || (),
-        $self->program, $action, $self->list, @options );
+    $uri->path( join '/', $self->prefix || (), $self->program, @parts );
     return $uri;
 }
 
+sub _uri_for {
+    my ( $self, $action, @options ) = @_;
+    return $self->__uri_for( $action, $self->list, @options )
+}
+
 sub _login_form {
     my ($self) = @_;
     my $mech = $self->robot;
@@ -683,11 +690,18 @@ available and the privacy settings of the list.
 
 =item version( )
 
-Returm the Mailman version as printed at the bottom of all pages.
+Return the Mailman version as printed at the bottom of all pages.
 
 Whenever WWW::Mailman downloads a Mailman web page, it tries to obtain
 this version information.
 
+=item archive_mbox_uri( )
+
+Return the URI of the mbox containing the whole mailing-list archive.
+
+If archival is not configured for that mailing-list, querying this URI
+will return a 404.
+
 =back
 
 
